@@ -42,8 +42,7 @@ class UUIDField(models.CharField) :
 
 class PaypalAdaptive(models.Model):
     """Base fields used by all PaypalAdaptive models"""
-
-    money = MoneyField(_(u'money'), max_digits=6, decimal_places=2)
+    money = MoneyField(_(u'money'), max_digits=9, decimal_places=2)
     created_date = models.DateTimeField(_(u'created on'), auto_now_add=True)
     secret_uuid = UUIDField(_(u'secret UUID'))  # to verify return_url
     debug_request = models.TextField(_(u'raw request'), blank=True, null=True)
@@ -120,7 +119,7 @@ class Payment(PaypalAdaptive):
     @property
     def cancel_url(self):
         current_site = Site.objects.get_current()
-        kwargs = {'payment_id': self.id}
+        kwargs = {'payment_id': self.id, 'secret_uuid': self.secret_uuid}
         cancel_url = reverse('paypal-adaptive-payment-cancel', kwargs=kwargs)
         return "http://%s%s" % (current_site, cancel_url)
 
@@ -166,8 +165,8 @@ class Payment(PaypalAdaptive):
         if not isinstance(receivers, api.ReceiverList):
             raise ValueError("receivers must be an instance of "
                              "ReceiverList")
-        elif not receivers.has_primary():
-            receivers._receivers[0].primary = True
+        elif not receivers.has_primary() and settings.USE_CHAIN:
+            receivers.receivers[0].primary = True
 
         endpoint_kwargs.update({'receivers': receivers})
 
