@@ -25,7 +25,7 @@ PAYPAL_SIGNATURE = settings.PAYPAL_SIGNATURE
 PAYPAL_EMAIL = settings.PAYPAL_EMAIL
 
 USE_IPN = getattr(settings, 'PAYPAL_USE_IPN', True)
-USE_CHAIN = getattr(settings, 'PAYPAL_USE_CHAIN', False)
+USE_CHAIN = getattr(settings, 'PAYPAL_USE_CHAIN', True)
 USE_EMBEDDED = getattr(settings, 'PAYPAL_USE_EMBEDDED', True)
 SHIPPING = getattr(settings, 'PAYPAL_USE_SHIPPING', False)
 
@@ -33,4 +33,4 @@ DEFAULT_CURRENCY = getattr(settings, 'DEFAULT_CURRENCY', 'USD')
 set_default_currency(code=DEFAULT_CURRENCY)
 
 # Should tests hit Paypaladaptive or not? Defaults to using mock responses
-TEST_WITH_MOCK = getattr(settings, 'PAYPAL_TEST_WITH_MOCK', True)
\ No newline at end of file
+TEST_WITH_MOCK = getattr(settings, 'PAYPAL_TEST_WITH_MOCK', True)
