@@ -1,6 +1,7 @@
-from tests import *
+from tests import AdaptiveTests
 from ipn import TestPaymentIPN, TestPreapprovalIPN, TestIPNVerification
 from preapproval_return_url import TestPreapprovalReturnURL
 from preapproval_cancel import TestPreapprovalCancel
 from payment_return_url import TestPaymentReturnURL
 from payment_response import TestPaymentResponses
+from payment import PaymentDBTest
